pub struct UploadKeyPackageRequest {
pub key_package: Option<KeyPackageUpload>,
pub is_inbox_id_credential: bool,
}Expand description
Upload a new key packages
Fields
key_package: Option<KeyPackageUpload>An individual key package upload request
is_inbox_id_credential: boolTrait Implementations
Sourceimpl Clone for UploadKeyPackageRequest
impl Clone for UploadKeyPackageRequest
Sourcefn clone(&self) -> UploadKeyPackageRequest
fn clone(&self) -> UploadKeyPackageRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UploadKeyPackageRequest
impl Debug for UploadKeyPackageRequest
Sourceimpl Default for UploadKeyPackageRequest
impl Default for UploadKeyPackageRequest
impl<'de> Deserialize<'de> for UploadKeyPackageRequest
impl<'de> Deserialize<'de> for UploadKeyPackageRequest
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for UploadKeyPackageRequest
impl Hash for UploadKeyPackageRequest
Sourceimpl Message for UploadKeyPackageRequest
impl Message for UploadKeyPackageRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Name for UploadKeyPackageRequest
impl Name for UploadKeyPackageRequest
Sourceconst NAME: &'static str = "UploadKeyPackageRequest"
const NAME: &'static str = "UploadKeyPackageRequest"
Simple name for this
Message.
This name is the same as it appears in the source .proto file, e.g. FooBar.Sourceconst PACKAGE: &'static str = "xmtp.mls.api.v1"
const PACKAGE: &'static str = "xmtp.mls.api.v1"
Package name this message type is contained in. They are domain-like
and delimited by
., e.g. google.protobuf.Sourcefn full_name() -> String
fn full_name() -> String
Fully-qualified unique name for this
Message.
It’s prefixed with the package name and names of any parent messages,
e.g. google.rpc.BadRequest.FieldViolation.
By default, this is the package name followed by the message name.
Fully-qualified names must be unique within a domain of Type URLs.Sourceimpl PartialEq for UploadKeyPackageRequest
impl PartialEq for UploadKeyPackageRequest
Sourcefn eq(&self, other: &UploadKeyPackageRequest) -> bool
fn eq(&self, other: &UploadKeyPackageRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Serialize for UploadKeyPackageRequest
impl Serialize for UploadKeyPackageRequest
impl Eq for UploadKeyPackageRequest
impl StructuralPartialEq for UploadKeyPackageRequest